=======
Credits
=======

Development Lead
----------------

* Simon Birrer <sibirrer@gmail.com>

Contributors (alphabetical)
---------------------------

* Aymeric Galan `aymgal <https://github.com/aymgal/>`_
* Martin Millon `martin-millon <https://github.com/martin-millon>`_
* Ji Won Park `jiwoncpark <https://github.com/jiwoncpark/>`_
* Anowar Shajib `ajshajib <https://github.com/ajshajib>`_
* William Sheu `williyamshoe <https://github.com/williyamshoe>`_
* Chin-Yi Tan `chinyitan <https://github.com/chinyitan>`_
